#include <DFRobot_SHT3x.h>

DFRobot_SHT3x sht3x;

#define LED 4

volatile  int alertState = 0;
void alert(){
  alertState = 1 - alertState;
}


void setup() 
{
  Serial.begin(9600);
  pinMode(LED,OUTPUT);
  digitalWrite(LED,LOW);
  attachInterrupt(/*Interrupt No*/0,alert,CHANGE);  //UNO(2), Mega2560(2), Leonardo(3), microbit(P0).中断引脚
  while (sht3x.begin() != 0) //初始化是否成功
  {
    Serial.println("The initialization of the chip is failed, please confirm whether the chip connection is correct");
    delay(1000);
  }
  if(!sht3x.softReset()){
     Serial.println("Failed to reset the chip");
   }
  sht3x.clearStatusRegister();
  if(!sht3x.startPeriodicMode(sht3x.eMeasureFreq_10Hz))
  {
    Serial.println("Failed to enter the periodic mode");
  }
  if(sht3x.setTemperatureLimitC(/*highset=*/28,/*highClear=*/27,/*lowSet=*/15,/*lowClear=*/17) != 0){
    Serial.println("Failed to set the temperature limit");
  }
  if(sht3x.setHumidityLimitRH(/*highset=*/70,/*highClear=*/68,/*lowSet=*/19,/*lowClear=*/20) != 0){
    Serial.println("Failed to set the humidity limit");
  }
  ////前面全部正常，就会显示这一步
  Serial.println(F("----------------------Alarm Detection-------------------------------"));
  Serial.println(F("Alarms raised when temp and humidity are out of the threshold range. Please connect ALERT to the main control board interrupt pin"));
  Serial.println(F("-Different main contorl UNO(2), Mega2560(2), Leonardo(3), microbit(P0), mPython(P16)----"));
  Serial.println(F("----------------------the humidity limit(%RH)-----------------------------------"));
  if(sht3x.measureHumidityLimitRH()){
    Serial.print("high set:");
    //getHumidityHighSetRH() Get the high humidity alarm point
    Serial.print(sht3x.getHumidityHighSetRH());
    Serial.print("               low clear:");
    //getHumidityHighClearRH() Get the high humidity alarm clear point
    Serial.println(sht3x.getHumidityLowClearRH());
    Serial.print("high clear:");
    //getHumidityLowClearRH() Get the low humidity alarm clear point
    Serial.print(sht3x.getHumidityHighClearRH());
    Serial.print("               low set:");
    //getHumidityLowSetRH() Get the low humidity alarm point
    Serial.println(sht3x.getHumidityLowSetRH());
  } else {
    Serial.println("Failed to get the humidity limit");
  }
  Serial.println("----------------------temperature limit(°C)---------------------------------");
  if(sht3x.measureTemperatureLimitC()){
    Serial.print("high set:");
    Serial.print(sht3x.getTemperatureHighSetC());
    Serial.print("               low clear:");
    Serial.println(sht3x.getTemperatureLowClearC());
    Serial.print("high clear:");
    Serial.print(sht3x.getTemperatureHighClearC());
    Serial.print("               low set:");
    Serial.println(sht3x.getTemperatureLowSetC());
    Serial.println("------------------------------------------------------------------");
  } else {
    Serial.println("Failed to get temperature limit");
  }
  if(sht3x.readAlertState() == 1){
    alertState = 1;
  } else {
    alertState = 0;
  }

}

void loop() 
{
  Serial.print("environment temperature(°C/F):");
  Serial.print(sht3x.getTemperatureC());
  Serial.print(" C/");
  Serial.print(sht3x.getTemperatureF());
  Serial.print(" F      ");
  Serial.print("relative humidity(%RH):");
  Serial.print(sht3x.getHumidityRH());
  Serial.println(" %RH");
  if(alertState == 1)
  {
    uint8_t state = sht3x.environmentState();
    if(state == 2 || state == 20 )
    {
      Serial.println(F("The humidity exceeds the upper threshold range!"));
      Serial.println(F("The temperature exceeds the upper threshold range!"));
      digitalWrite(LED,HIGH);      
    }
//    if(state == 1)  Serial.println(F("The humidity exceeds the lower threshold range!"));
//    else if(state == 10)  Serial.println(F("The temperature exceeds the lower threshold range!"));
//    else if(state == 11)  Serial.println(F("The humidity and the temperature exceed the lower threshold range!"));
//    else if(state == 2)   Serial.println(F("The humidity exceeds the upper threshold range!"));
//    else if(state == 20)  Serial.println(F("The temperature exceeds the upper threshold range!"));
//    else if(state == 22)  Serial.println(F("The humidity and the temperature exceed the upper threshold range!"));
//    else if(state == 12)  Serial.println(F("The temperature exceeds the lower threshold range,the humidity exceeds the upper threshold range!"));
//    else if(state == 21)  Serial.println(F("The temperature exceeds the upper threshold range, and the humidity exceeds the lower threshold range!"));
//    else Serial.println(F("T&H back to normal, but the alarm is not cleared!"));
  } 
  else 
  {
    digitalWrite(LED,LOW);
    Serial.println(F("T&H in normal range, alarm cleared"));
  }
  delay(1000);

}